AnyTarget CLI
=============

This cli created to seamlessly interact with the [anytarget.net](https://anytarget.net) API.
you can executing `search`, `stats`, `download` commands and, organizing data display.


Installing
----------

```sh
git clone https://github.com/caelghoul/anytarget.git
cd anytarget
pip install -r requirements.txt
python setup.py install
```

or

```sh
pip install anytarget
```

Setup
----------

```sh
anytarget auth "YOUR-API-KEY"
```


